================================
CFFI documentation
================================

C Foreign Function Interface for Python.  Interact with almost any C
code from Python, based on C-like declarations that you can often
copy-paste from header files or documentation.

.. toctree::
   :maxdepth: 2

   goals
   whatsnew
   installation
   overview
   using
   ref
   cdef
   embedding



